@@ -492,7 +492,7 @@ class DataTransformerForm(BaseInlineFormSet):
                                                              fk_name='parent',
                                                              extra=1, exclude=['updated_at', 'created_at'], form=DataTransform
                                                              )
-        if form.instance is not None:
+        if form.instance is not None and hasattr(form.instance, 'getChildren'):
             form.nested_data_transformer_form = dataTransformerInlineFormset(
                 initial=form.instance.getChildren(),
                 data=form.data if form.is_bound else None,
